'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));

// eslint-disable react-hooks/exhaustive-deps

function shallowEquals(a, b) {
  var isEqual = true; // technically equal but we always run effects with there are no dependencies

  if (a === undefined && b === undefined) {
    isEqual = false; // compare array *values* and length
  } else if (Array.isArray(a) && Array.isArray(b)) {
    for (var i in a) {
      if (!Object.is(a[i], b[i])) isEqual = false;
    }

    if (a.length !== b.length) isEqual = false; // compare everything else by identity
  } else {
    isEqual = Object.is(a, b);
  }

  return isEqual;
}

function getArtificialDependency() {
  return {};
}

function useConditionalEffect(callback, dependencies, isEqual) {
  if (isEqual === void 0) {
    isEqual = shallowEquals;
  }

  var lastDependenciesValue = React.useRef(undefined);
  var artificialDep = React.useRef(getArtificialDependency());
  var shouldRunEffect = !isEqual(dependencies, lastDependenciesValue.current);
  React.useEffect(callback, shouldRunEffect ? [artificialDep.current = getArtificialDependency()] : [artificialDep.current]);
  lastDependenciesValue.current = dependencies;
}

module.exports = useConditionalEffect;
